.. _glossary:

Glossary
********

.. glossary::

    adjacency
        Square matrix whose entries indicate edges between nodes of a graph, usually denoted by :math:`A`.

    biadjacency
        Rectangular matrix whose entries indicate edges between nodes of a bipartite graph,
        usually denoted by :math:`B`.

    embedding
        Mapping of the nodes of a graph to points in a vector space.
